local M = {}

local helper = require('scenario/scenariohelper')
local logTag = 'Mountain_race'

local finalWaypointName = 'waypoint_8'
local playerInstance = 'scenario_player0'
local aiInstance = 'scenario_truck'
local playerVehicle = scenetree.findObject('scenario_truck')
local running = false
local playerWon = false
local aiWon = false

local function reset()
  running = false
  playerWon = false
  aiWon = false
end

local function fail(reason)
  scenario_scenarios.finish({failed = reason})
  reset()
end

local function success(reason)
  scenario_scenarios.finish({msg = reason})
  reset()
end

local function onRaceStart()
	  reset()
	  
	  playerVehicle:queueLuaCommand('beamstate.toggleCouplers()')

	  local arg = {vehicleName = 'scenario_truck',
				  waypoints = {'bridge_damwall_a', 'bridge_damwall_b', 'bridge_damwall_c', 'bridge_damwall_d', finalWaypointName},
				  aggression = 0.5, -- aggression here acts as a multiplier to the Ai default aggression i.e. 0.7.
				  routeSpeed = 40/3.6,  ---10/3.6=7, 40/3.6=37
				  routeSpeedMode = 'limit',
				  }

	  helper.setAiPath(arg)
	  
	  scenario_scenarios.trackVehicleMovementAfterDamage(playerInstance, {waitTimerLimit=2})
	  running = true

end

local function onRaceWaypointReached(data)
  if data.waypointName == finalWaypointName then
    if data.vehicleName == playerInstance and not aiWon then
      playerWon = true
    elseif data.vehicleName == aiInstance and not playerWon then
      aiWon = true
    end
  end
end

local function onRaceResult()
  if playerWon then
    success('Congratulations! you just achieved the most epic or the most senseless overtake in history, depending on your point of view')
  else
    fail('You probably should have stuck to the road')
  end
end


M.onRaceStart = onRaceStart
M.onRaceWaypointReached = onRaceWaypointReached
M.onRaceResult = onRaceResult
M.onVehicleStoppedMoving = onVehicleStoppedMoving
return M